@@ -1,20 +1,17 @@
 from __future__ import annotations
 
+from asyncio import sleep
 from io import StringIO
-from logging import DEBUG, NOTSET, FileHandler, Logger, StreamHandler, getLogger
+from logging import Formatter, Logger, StreamHandler, getLogger
 from pathlib import Path
 from re import search
-from time import sleep
-from typing import TYPE_CHECKING, Any, Literal, cast
+from typing import TYPE_CHECKING, Any, cast
 
 from hypothesis import given
 from hypothesis.strategies import booleans, integers, none, sampled_from
 from pytest import LogCaptureFixture, mark, param, raises
-from whenever import ZonedDateTime
 
-from tests.test_traceback_funcs.one import func_one
-from tests.test_traceback_funcs.untraced import func_untraced
-from utilities.datetime import NOW_UTC, SECOND, serialize_compact
+from tests.conftest import SKIPIF_CI_AND_WINDOWS
 from utilities.hypothesis import (
     assume_does_not_raise,
     pairs,
@@ -27,35 +24,34 @@ from utilities.logging import (
     FilterForKeyError,
     GetLoggingLevelNumberError,
     SizeAndTimeRotatingFileHandler,
-    StandaloneFileHandler,
-    _AdvancedLogRecord,
     _compute_rollover_actions,
+    _FieldStyleKeys,
     _RotatingLogFile,
     add_filters,
     basic_config,
     filter_for_key,
-    get_default_logging_path,
+    get_formatter,
     get_logger,
     get_logging_level_number,
     setup_logging,
-    temp_handler,
-    temp_logger,
 )
-from utilities.pytest import skipif_windows
+from utilities.text import unique_str
 from utilities.types import LogLevel
 from utilities.typing import get_args
+from utilities.whenever import format_compact, get_now, to_local_plain
 
 if TYPE_CHECKING:
-    import datetime as dt
-    from re import Pattern
+    from collections.abc import Mapping
+    from contextlib import AbstractContextManager
+    from logging import _FilterType
 
-    from utilities.types import LoggerOrName
+    from whenever import ZonedDateTime
 
 
 class TestAddFilters:
-    @given(root=temp_paths(), expected=booleans())
-    def test_main(self, *, root: Path, expected: bool) -> None:
-        logger = getLogger(str(root))
+    @given(expected=booleans())
+    def test_main(self, *, expected: bool) -> None:
+        logger = getLogger(unique_str())
         logger.addHandler(handler := StreamHandler(buffer := StringIO()))
         add_filters(handler, lambda _: expected)
         assert len(handler.filters) == 1
@@ -71,15 +67,36 @@ class TestAddFilters:
 
 
 class TestBasicConfig:
-    def test_main(self, *, tmp_path: Path) -> None:
-        basic_config()
-        logger = getLogger(str(tmp_path))
-        logger.info("message")
+    @mark.parametrize(
+        "filters",
+        [
+            param(lambda _: True),  # pyright: ignore[reportUnknownLambdaType]
+            param(None),
+        ],
+    )
+    @mark.parametrize("plain", [param(True), param(False)])
+    def test_main(
+        self,
+        *,
+        caplog: LogCaptureFixture,
+        filters: _FilterType | None,
+        plain: bool,
+        set_log_factory: AbstractContextManager[None],
+    ) -> None:
+        name = unique_str()
+        with set_log_factory:
+            basic_config(obj=name, filters=filters, plain=plain)
+        getLogger(name).warning("message")
+        record = one(r for r in caplog.records if r.name == name)
+        assert record.message == "message"
+
+    def test_none(self, *, set_log_factory: AbstractContextManager[None]) -> None:
+        with set_log_factory:
+            basic_config()
 
 
 class TestComputeRolloverActions:
-    @skipif_windows
-    def test_main(self, *, tmp_path: Path) -> None:
+    async def test_main(self, *, tmp_path: Path) -> None:
         tmp_path.joinpath("log.txt").touch()
 
         actions = _compute_rollover_actions(tmp_path, "log", ".txt")
@@ -91,7 +108,7 @@ class TestComputeRolloverActions:
         assert any(p for p in files if search(r"^log\.1\__[\dT]+\.txt$", p.name))
 
         for _ in range(2):
-            sleep(1)
+            await sleep(1)
             tmp_path.joinpath("log.txt").touch()
             actions = _compute_rollover_actions(tmp_path, "log", ".txt")
             assert len(actions.deletions) == 1
@@ -103,8 +120,7 @@ class TestComputeRolloverActions:
                 p for p in files if search(r"^log\.1\__[\dT]+__[\dT]+\.txt$", p.name)
             )
 
-    @skipif_windows
-    def test_multiple_backups(self, *, tmp_path: Path) -> None:
+    async def test_multiple_backups(self, *, tmp_path: Path) -> None:
         tmp_path.joinpath("log.txt").touch()
 
         actions = _compute_rollover_actions(tmp_path, "log", ".txt", backup_count=3)
@@ -115,7 +131,7 @@ class TestComputeRolloverActions:
         assert len(files) == 1
         assert any(p for p in files if search(r"^log\.1\__[\dT]+\.txt$", p.name))
 
-        sleep(1)
+        await sleep(1)
         tmp_path.joinpath("log.txt").touch()
         actions = _compute_rollover_actions(tmp_path, "log", ".txt", backup_count=3)
         assert len(actions.deletions) == 0
@@ -128,7 +144,7 @@ class TestComputeRolloverActions:
         )
         assert any(p for p in files if search(r"^log\.2\__[\dT]+\.txt$", p.name))
 
-        sleep(1)
+        await sleep(1)
         tmp_path.joinpath("log.txt").touch()
         actions = _compute_rollover_actions(tmp_path, "log", ".txt", backup_count=3)
         assert len(actions.deletions) == 0
@@ -145,7 +161,7 @@ class TestComputeRolloverActions:
         assert all(p for p in files if search(r"^log\.3\__[\dT]+\.txt$", p.name))
 
         for _ in range(2):
-            sleep(1)
+            await sleep(1)
             tmp_path.joinpath("log.txt").touch()
             actions = _compute_rollover_actions(tmp_path, "log", ".txt", backup_count=3)
             assert len(actions.deletions) == 1
@@ -163,8 +179,7 @@ class TestComputeRolloverActions:
                 p for p in files if search(r"^log\.3\__[\dT]+__[\dT]+\.txt$", p.name)
             )
 
-    @skipif_windows
-    def test_deleting_old_files(self, *, tmp_path: Path) -> None:
+    async def test_deleting_old_files(self, *, tmp_path: Path) -> None:
         tmp_path.joinpath("log.txt").touch()
 
         actions = _compute_rollover_actions(tmp_path, "log", ".txt")
@@ -175,9 +190,9 @@ class TestComputeRolloverActions:
         assert len(files) == 1
         assert any(p for p in files if search(r"^log\.1\__[\dT]+\.txt$", p.name))
 
-        sleep(1)
+        await sleep(1)
         tmp_path.joinpath("log.txt").touch()
-        now = serialize_compact(NOW_UTC)
+        now = format_compact(to_local_plain(get_now()))
         tmp_path.joinpath(f"log.99__{now}__{now}.txt").touch()
         actions = _compute_rollover_actions(tmp_path, "log", ".txt")
         assert len(actions.deletions) == 2
@@ -191,16 +206,9 @@ class TestComputeRolloverActions:
 
 
 class TestFilterForKey:
-    @given(
-        root=temp_paths(),
-        key=text_ascii(),
-        value=booleans() | none(),
-        default=booleans(),
-    )
-    def test_main(
-        self, *, root: Path, key: str, value: bool | None, default: bool
-    ) -> None:
-        logger = getLogger(str(root))
+    @given(key=text_ascii(), value=booleans() | none(), default=booleans())
+    def test_main(self, *, key: str, value: bool | None, default: bool) -> None:
+        logger = getLogger(unique_str())
         logger.addHandler(handler := StreamHandler(buffer := StringIO()))
         with assume_does_not_raise(FilterForKeyError):
             filter_ = filter_for_key(key, default=default)
@@ -224,21 +232,34 @@ class TestFilterForKey:
             _ = filter_for_key(key)
 
 
-class TestGetDefaultLoggingPath:
-    def test_main(self) -> None:
-        assert isinstance(get_default_logging_path(), Path)
+class TestGetFormatter:
+    @mark.parametrize("plain", [param(True), param(False)])
+    @mark.parametrize("color_field_styles", [param({}), param(None)])
+    def test_main(
+        self,
+        *,
+        plain: bool,
+        color_field_styles: Mapping[str, _FieldStyleKeys] | None,
+        set_log_factory: AbstractContextManager[None],
+    ) -> None:
+        with set_log_factory:
+            formatter = get_formatter(
+                plain=plain, color_field_styles=color_field_styles
+            )
+        assert isinstance(formatter, Formatter)
 
 
 class TestGetLogger:
-    def test_logger(self, *, tmp_path: Path) -> None:
-        logger = getLogger(str(tmp_path))
+    def test_logger(self) -> None:
+        logger = getLogger(unique_str())
         result = get_logger(logger=logger)
         assert result is logger
 
-    def test_str(self, *, tmp_path: Path) -> None:
-        result = get_logger(logger=str(tmp_path))
-        assert isinstance(result, Logger)
-        assert result.name == str(tmp_path)
+    def test_str(self) -> None:
+        name = unique_str()
+        logger = getLogger(name)
+        assert isinstance(logger, Logger)
+        assert logger.name == name
 
     def test_none(self) -> None:
         result = get_logger()
@@ -294,42 +315,34 @@ class TestRotatingLogFile:
         assert result.start is None
         assert result.end is None
 
-    @given(
-        index=integers(min_value=1),
-        end=zoned_datetimes(round_="standard", timedelta=SECOND),
-    )
+    @given(index=integers(min_value=1), end=zoned_datetimes())
     def test_from_path_with_index_and_end(
-        self, *, index: int, end: dt.datetime
+        self, *, index: int, end: ZonedDateTime
     ) -> None:
-        path = Path(f"log.{index}__{serialize_compact(end)}.txt")
+        path = Path(f"log.{index}__{format_compact(to_local_plain(end))}.txt")
         result = _RotatingLogFile.from_path(path, "log", ".txt")
         assert result is not None
         assert result.stem == "log"
         assert result.suffix == ".txt"
         assert result.index == index
         assert result.start is None
-        assert result.end == end
+        assert result.end == end.round()
 
-    @given(
-        index=integers(min_value=1),
-        datetimes=pairs(
-            zoned_datetimes(round_="standard", timedelta=SECOND), sorted=True
-        ),
-    )
+    @given(index=integers(min_value=1), datetimes=pairs(zoned_datetimes(), sorted=True))
     def test_from_path_with_index_start_and_end(
-        self, *, index: int, datetimes: tuple[dt.datetime, dt.datetime]
+        self, *, index: int, datetimes: tuple[ZonedDateTime, ZonedDateTime]
     ) -> None:
         start, end = datetimes
         path = Path(
-            f"log.{index}__{serialize_compact(start)}__{serialize_compact(end)}.txt"
+            f"log.{index}__{format_compact(to_local_plain(start))}__{format_compact(to_local_plain(end))}.txt"
         )
         result = _RotatingLogFile.from_path(path, "log", ".txt")
         assert result is not None
         assert result.stem == "log"
         assert result.suffix == ".txt"
         assert result.index == index
-        assert result.start == start
-        assert result.end == end
+        assert result.start == start.round()
+        assert result.end == end.round()
 
     def test_from_path_none(self) -> None:
         path = Path("invalid.txt")
@@ -345,232 +358,130 @@ class TestRotatingLogFile:
         file = _RotatingLogFile(directory=root, stem="log", suffix=".txt", index=index)
         assert file.path == root.joinpath(f"log.{index}.txt")
 
-    @given(
-        root=temp_paths(),
-        index=integers(min_value=1),
-        end=zoned_datetimes(round_="standard", timedelta=SECOND),
-    )
+    @given(root=temp_paths(), index=integers(min_value=1), end=zoned_datetimes())
     def test_path_with_index_and_end(
-        self, *, root: Path, index: int, end: dt.datetime
+        self, *, root: Path, index: int, end: ZonedDateTime
     ) -> None:
         file = _RotatingLogFile(
             directory=root, stem="log", suffix=".txt", index=index, end=end
         )
-        assert file.path == root.joinpath(f"log.{index}__{serialize_compact(end)}.txt")
+        assert file.path == root.joinpath(
+            f"log.{index}__{format_compact(to_local_plain(end))}.txt"
+        )
 
     @given(
         root=temp_paths(),
         index=integers(min_value=1),
-        datetimes=pairs(
-            zoned_datetimes(round_="standard", timedelta=SECOND), sorted=True
-        ),
+        datetimes=pairs(zoned_datetimes(), sorted=True),
     )
     def test_path_with_index_start_and_end(
-        self, *, root: Path, index: int, datetimes: tuple[dt.datetime, dt.datetime]
+        self, *, root: Path, index: int, datetimes: tuple[ZonedDateTime, ZonedDateTime]
     ) -> None:
         start, end = datetimes
         file = _RotatingLogFile(
             directory=root, stem="log", suffix=".txt", index=index, start=start, end=end
         )
         assert file.path == root.joinpath(
-            f"log.{index}__{serialize_compact(start)}__{serialize_compact(end)}.txt"
+            f"log.{index}__{format_compact(to_local_plain(start))}__{format_compact(to_local_plain(end))}.txt"
         )
 
 
 class TestSetupLogging:
-    @skipif_windows
-    def test_decorated(
-        self, *, tmp_path: Path, traceback_func_one: Pattern[str]
-    ) -> None:
-        name = str(tmp_path)
+    def test_main(self, *, tmp_path: Path) -> None:
+        name = unique_str()
         setup_logging(logger=name, files_dir=tmp_path)
         logger = getLogger(name)
         assert len(logger.handlers) == 7
-        self.assert_files(tmp_path, "init")
-        try:
-            _ = func_one(1, 2, 3, 4, c=5, d=6, e=7)
-        except AssertionError:
-            logger.exception("message")
-        self.assert_files(tmp_path, ("post", traceback_func_one))
-
-    @skipif_windows
-    def test_undecorated(
-        self, *, tmp_path: Path, traceback_func_untraced: Pattern[str]
-    ) -> None:
-        name = str(tmp_path)
-        setup_logging(logger=name, files_dir=tmp_path)
-        logger = getLogger(name)
-        assert len(logger.handlers) == 7
-        self.assert_files(tmp_path, "init")
-        try:
-            _ = func_untraced(1, 2, 3, 4, c=5, d=6, e=7)
-        except AssertionError:
-            logger.exception("message")
-        self.assert_files(tmp_path, ("post", traceback_func_untraced))
-
-    @skipif_windows
-    def test_regular_percent_formatting(
-        self, *, tmp_path: Path, caplog: LogCaptureFixture
-    ) -> None:
-        name = str(tmp_path)
-        setup_logging(logger=name, files_dir=tmp_path)
-        logger = getLogger(name)
-        logger.info("int: %d, float: %.2f", 1, 12.3456)
-        record = one(caplog.records)
-        assert isinstance(record, _AdvancedLogRecord)
-        expected = "int: 1, float: 12.35"
-        assert record.message == expected
-
-    @skipif_windows
-    def test_new_brace_formatting(
-        self, *, tmp_path: Path, caplog: LogCaptureFixture
-    ) -> None:
-        name = str(tmp_path)
-        setup_logging(logger=name, files_dir=tmp_path)
-        logger = getLogger(name)
-        logger.info("int: {:d}, float: {:.2f}, percent: {:.2%}", 1, 12.3456, 0.123456)
-        record = one(caplog.records)
-        assert isinstance(record, _AdvancedLogRecord)
-        expected = "int: 1, float: 12.35, percent: 12.35%"
-        assert record.message == expected
-
-    @skipif_windows
-    def test_no_console(self, *, tmp_path: Path) -> None:
-        name = str(tmp_path)
-        setup_logging(logger=name, console_level=None, files_dir=tmp_path)
-        logger = getLogger(name)
-        assert len(logger.handlers) == 5
-
-    @skipif_windows
-    def test_zoned_datetime(self, *, tmp_path: Path, caplog: LogCaptureFixture) -> None:
-        name = str(tmp_path)
-        setup_logging(logger=name, files_dir=tmp_path)
-        logger = getLogger(name)
-        logger.info("")
-        record = one(caplog.records)
-        assert isinstance(record, _AdvancedLogRecord)
-        assert isinstance(record._zoned_datetime, ZonedDateTime)
-        assert isinstance(record._zoned_datetime_str, str)
-
-    @skipif_windows
-    def test_extra(self, *, tmp_path: Path) -> None:
-        name = str(tmp_path)
-
-        def extra(logger: LoggerOrName | None, /) -> None:
-            get_logger(logger=logger).addHandler(
-                FileHandler(tmp_path.joinpath("extra.log"))
-            )
-
-        setup_logging(logger=name, files_dir=tmp_path, extra=extra)
-        logger = getLogger(name)
-        logger.info("")
-        files = list(tmp_path.iterdir())
-        names = {f.name for f in files}
-        assert len(names) == 4
-
-    @classmethod
-    def assert_files(
-        cls, path: Path, check: Literal["init"] | tuple[Literal["post"], Pattern[str]]
-    ) -> None:
-        files = list(path.iterdir())
-        names = {f.name for f in files}
-        match check:
-            case "init":
-                assert names == {"debug.txt", "info.txt", "plain"}
-            case "post", pattern:
-                assert names == {"debug.txt", "info.txt", "errors", "plain"}
-                errors = path.joinpath("errors")
-                assert errors.is_dir()
-                files = list(errors.iterdir())
-                assert len(files) == 1
-                with one(files).open() as fh:
-                    contents = fh.read()
-                assert pattern.search(contents)
+        logger.warning("message")
+        files = {p.name for p in tmp_path.iterdir() if p.is_file()}
+        expected = {
+            "debug.txt",
+            "info.txt",
+            "error.txt",
+            f"{name}-debug.txt",
+            f"{name}-info.txt",
+            f"{name}-error.txt",
+        }
+        assert files == expected
 
 
 class TestSizeAndTimeRotatingFileHandler:
-    @skipif_windows
     def test_handlers(self, *, tmp_path: Path) -> None:
-        logger = getLogger(str(tmp_path))
+        logger = getLogger(unique_str())
         filename = tmp_path.joinpath("log")
         logger.addHandler(SizeAndTimeRotatingFileHandler(filename=filename))
         logger.warning("message")
-        with filename.open() as fh:
-            content = fh.read()
+        content = filename.read_text()
         assert content == "message\n"
 
-    @skipif_windows
-    def test_size(self, *, tmp_path: Path) -> None:
-        logger = getLogger(str(tmp_path))
+    def test_create_parents(self, *, tmp_path: Path) -> None:
+        logger = getLogger(unique_str())
+        filename = tmp_path.joinpath("foo", "bar", "bar", "log")
+        logger.addHandler(SizeAndTimeRotatingFileHandler(filename=filename))
+        assert filename.exists()
+
+    @SKIPIF_CI_AND_WINDOWS
+    async def test_size(self, *, tmp_path: Path) -> None:
+        logger = getLogger(unique_str())
         logger.addHandler(
             SizeAndTimeRotatingFileHandler(
                 filename=tmp_path.joinpath("log.txt"), maxBytes=100, backupCount=3
             )
         )
-
-        for i in range(1, 3):
-            logger.warning("message %d", i)
-            files = list(tmp_path.iterdir())
-            assert len(files) == 1
-            assert any(p for p in files if search(r"^log\.txt$", p.name))
-
-        logger.warning(10 * "message 3")
-        files = list(tmp_path.iterdir())
-        assert len(files) == 2
-        assert any(p for p in files if search(r"^log\.txt$", p.name))
-        assert any(p for p in files if search(r"^log\.1__[\dT]+\.txt$", p.name))
-
-        for i in range(4, 6):
-            logger.warning("message %d", i)
-            files = list(tmp_path.iterdir())
-            assert len(files) == 3
-            assert any(p for p in files if search(r"^log\.txt$", p.name))
-            assert any(
-                p for p in files if search(r"^log\.1__[\dT]+__[\dT]+\.txt$", p.name)
-            )
-            assert any(p for p in files if search(r"^log\.2__[\dT]+\.txt$", p.name))
-
-        logger.warning(10 * "message 6")
-        files = list(tmp_path.iterdir())
-        assert len(files) == 4
-        assert any(p for p in files if search(r"^log\.txt$", p.name))
-        assert any(p for p in files if search(r"^log\.1__[\dT]+__[\dT]+\.txt$", p.name))
-        assert any(p for p in files if search(r"^log\.2__[\dT]+__[\dT]+\.txt$", p.name))
-        assert any(p for p in files if search(r"^log\.3__[\dT]+\.txt$", p.name))
-
-        for _ in range(2):
-            for i in range(7, 9):
-                logger.warning("message %d", i)
+        for cycle in range(1, 10):
+            for i in range(1, 4):
+                logger.warning("%s message %d", 100 * "long" if i % 3 == 0 else "", i)
                 files = list(tmp_path.iterdir())
-                assert len(files) == 4
+                assert len(files) == min(cycle, 4)
                 assert any(p for p in files if search(r"^log\.txt$", p.name))
-                assert any(
-                    p for p in files if search(r"^log\.1__[\dT]+__[\dT]+\.txt$", p.name)
-                )
-                assert any(
-                    p for p in files if search(r"^log\.2__[\dT]+__[\dT]+\.txt$", p.name)
-                )
-                assert any(
-                    p for p in files if search(r"^log\.3__[\dT]+__[\dT]+\.txt$", p.name)
-                )
+                if cycle == 2:
+                    assert any(
+                        p for p in files if search(r"^log\.1__[\dT]+\.txt$", p.name)
+                    )
+                elif cycle == 3:
+                    assert any(
+                        p
+                        for p in files
+                        if search(r"^log\.1__[\dT]+__[\dT]+\.txt$", p.name)
+                    )
+                    assert any(
+                        p for p in files if search(r"^log\.2__[\dT]+\.txt$", p.name)
+                    )
+                elif cycle == 4:
+                    assert any(
+                        p
+                        for p in files
+                        if search(r"^log\.1__[\dT]+__[\dT]+\.txt$", p.name)
+                    )
+                    assert any(
+                        p
+                        for p in files
+                        if search(r"^log\.2__[\dT]+__[\dT]+\.txt$", p.name)
+                    )
+                    assert any(
+                        p for p in files if search(r"^log\.3__[\dT]+\.txt$", p.name)
+                    )
+                elif cycle >= 5:
+                    assert any(
+                        p
+                        for p in files
+                        if search(r"^log\.1__[\dT]+__[\dT]+\.txt$", p.name)
+                    )
+                    assert any(
+                        p
+                        for p in files
+                        if search(r"^log\.2__[\dT]+__[\dT]+\.txt$", p.name)
+                    )
+                    assert any(
+                        p
+                        for p in files
+                        if search(r"^log\.3__[\dT]+__[\dT]+\.txt$", p.name)
+                    )
+                await sleep(0.1)
 
-            logger.warning("message 9")
-            files = list(tmp_path.iterdir())
-            assert len(files) == 4
-            assert any(p for p in files if search(r"^log\.txt$", p.name))
-            assert any(
-                p for p in files if search(r"^log\.1__[\dT]+__[\dT]+\.txt$", p.name)
-            )
-            assert any(
-                p for p in files if search(r"^log\.2__[\dT]+__[\dT]+\.txt$", p.name)
-            )
-            assert any(
-                p for p in files if search(r"^log\.3__[\dT]+__[\dT]+\.txt$", p.name)
-            )
-
-    @skipif_windows
-    def test_time(self, *, tmp_path: Path) -> None:
-        logger = getLogger(str(tmp_path))
+    @SKIPIF_CI_AND_WINDOWS
+    async def test_time(self, *, tmp_path: Path) -> None:
+        logger = getLogger(unique_str())
         logger.addHandler(
             SizeAndTimeRotatingFileHandler(
                 filename=tmp_path.joinpath("log.txt"),
@@ -589,7 +500,7 @@ class TestSizeAndTimeRotatingFileHandler:
         assert len(files) == 1
         assert any(p for p in files if search(r"^log\.txt$", p.name))
 
-        sleep(1.01)
+        await sleep(1.1)
         for i in range(2, 4):
             logger.warning("message %d", i)
             files = list(tmp_path.iterdir())
@@ -597,7 +508,7 @@ class TestSizeAndTimeRotatingFileHandler:
             assert any(p for p in files if search(r"^log\.txt$", p.name))
             assert any(p for p in files if search(r"^log\.1__[\dT]+\.txt$", p.name))
 
-        sleep(1.01)
+        await sleep(1.1)
         for i in range(4, 6):
             logger.warning("message %d", i)
             files = list(tmp_path.iterdir())
@@ -608,7 +519,7 @@ class TestSizeAndTimeRotatingFileHandler:
             )
             assert any(p for p in files if search(r"^log\.2__[\dT]+\.txt$", p.name))
 
-        sleep(1.01)
+        await sleep(1.1)
         for i in range(6, 8):
             logger.warning("message %d", i)
             files = list(tmp_path.iterdir())
@@ -623,7 +534,7 @@ class TestSizeAndTimeRotatingFileHandler:
             assert any(p for p in files if search(r"^log\.3__[\dT]+\.txt$", p.name))
 
         for _ in range(2):
-            sleep(1.01)
+            await sleep(1.1)
             for i in range(8, 10):
                 logger.warning("message %d", i)
                 files = list(tmp_path.iterdir())
@@ -639,67 +550,17 @@ class TestSizeAndTimeRotatingFileHandler:
                     p for p in files if search(r"^log\.3__[\dT]+__[\dT]+\.txt$", p.name)
                 )
 
-    @skipif_windows
+    @mark.parametrize("max_bytes", [param(0), param(1)])
+    @SKIPIF_CI_AND_WINDOWS
     def test_should_rollover_file_not_found(
-        self, *, tmp_path: Path, caplog: LogCaptureFixture
+        self, *, tmp_path: Path, max_bytes: int, caplog: LogCaptureFixture
     ) -> None:
-        logger = getLogger(str(tmp_path))
+        logger = getLogger(name := unique_str())
         path = tmp_path.joinpath("log")
         logger.addHandler(
-            handler := SizeAndTimeRotatingFileHandler(filename=path, maxBytes=1)
+            handler := SizeAndTimeRotatingFileHandler(filename=path, maxBytes=max_bytes)
         )
         logger.warning("message")
-        record = one(caplog.records)
+        record = one(r for r in caplog.records if r.name == name)
         path.unlink()
         assert not handler._should_rollover(record)
-
-
-class TestStandaloneFileHandler:
-    @skipif_windows
-    def test_main(self, *, tmp_path: Path) -> None:
-        logger = getLogger(str(tmp_path))
-        logger.addHandler(StandaloneFileHandler(level=DEBUG, path=tmp_path))
-        assert len(list(tmp_path.iterdir())) == 0
-        logger.warning("message")
-        files = list(tmp_path.iterdir())
-        assert len(files) == 1
-        with one(files).open() as fh:
-            contents = fh.read()
-        assert contents == "message"
-
-
-class TestTempHandler:
-    def test_main(self, *, tmp_path: Path) -> None:
-        logger = getLogger(str(tmp_path))
-        logger.addHandler(h1 := StreamHandler())
-        logger.addHandler(h2 := StreamHandler())
-        assert len(logger.handlers) == 2
-        handler = StreamHandler()
-        with temp_handler(handler, logger=logger):
-            assert len(logger.handlers) == 3
-        assert len(logger.handlers) == 2
-        assert logger.handlers[0] is h1
-        assert logger.handlers[1] is h2
-
-
-class TestTempLogger:
-    def test_disabled(self, *, tmp_path: Path) -> None:
-        logger = getLogger(str(tmp_path))
-        assert not logger.disabled
-        with temp_logger(logger, disabled=True):
-            assert logger.disabled
-        assert not logger.disabled
-
-    def test_level(self, *, tmp_path: Path) -> None:
-        logger = getLogger(str(tmp_path))
-        assert logger.level == NOTSET
-        with temp_logger(logger, level="DEBUG"):
-            assert logger.level == DEBUG
-        assert logger.level == NOTSET
-
-    def test_propagate(self, *, tmp_path: Path) -> None:
-        logger = getLogger(str(tmp_path))
-        assert logger.propagate
-        with temp_logger(logger, propagate=False):
-            assert not logger.propagate
-        assert logger.propagate
