@@ -8,7 +8,7 @@ from typing import TYPE_CHECKING, Any
 
 import polars as pl
 import sqlalchemy
-from hypothesis import Phase, given, settings
+from hypothesis import HealthCheck, Phase, given, settings
 from hypothesis.strategies import (
     DataObject,
     SearchStrategy,
@@ -86,8 +86,7 @@ from sqlalchemy import (
 from sqlalchemy.exc import DuplicateColumnError, OperationalError, ProgrammingError
 
 from tests.test_sqlalchemy import _table_names, _upsert_lists
-from utilities.datetime import are_equal_datetimes
-from utilities.hypothesis import sqlalchemy_engines, text_ascii, zoned_datetimes
+from utilities.hypothesis import int32s, text_ascii, zoned_datetimes
 from utilities.math import is_equal
 from utilities.polars import DatetimeUTC, check_polars_dataframe
 from utilities.sqlalchemy import ensure_tables_created
@@ -111,9 +110,7 @@ from utilities.sqlalchemy_polars import (
 if TYPE_CHECKING:
     from collections.abc import Callable, Iterable, Sequence
 
-    from polars._typing import (
-        PolarsDataType,  # pyright: ignore[reportPrivateImportUsage]
-    )
+    from polars._typing import PolarsDataType
     from polars.datatypes import DataTypeClass
     from sqlalchemy.ext.asyncio import AsyncEngine
 
@@ -125,129 +122,126 @@ _CASES_SELECT: list[
     (dates() | none(), pl.Date, sqlalchemy.Date, eq),
     (datetimes() | none(), Datetime, DateTime, eq),
     (
-        zoned_datetimes() | none(),
+        zoned_datetimes().map(lambda d: d.py_datetime()) | none(),
         DatetimeUTC,
         DateTime(timezone=True),
-        are_equal_datetimes,
+        eq,
     ),
     (floats(allow_nan=False) | none(), Float64, Float, is_equal),
-    (integers(-10, 10) | none(), Int64, Integer, eq),
+    (int32s() | none(), Int64, Integer, eq),
     (text_ascii() | none(), pl.String, sqlalchemy.String, eq),
 ]
 _CASES_INSERT: list[
     tuple[SearchStrategy[Any], PolarsDataType, Any, Callable[[Any, Any], bool]]
-] = [*_CASES_SELECT, (integers(-10, 10) | none(), Int32, Integer, eq)]
+] = [*_CASES_SELECT, (int32s() | none(), Int32, Integer, eq)]
 
 
 class TestInsertDataFrame:
-    @given(data=data(), name=_table_names(), case=sampled_from(_CASES_INSERT))
-    @settings(phases={Phase.generate})
+    @given(data=data())
+    @mark.parametrize(("strategy", "pl_dtype", "col_type", "check"), _CASES_INSERT)
+    @settings(
+        max_examples=1,
+        phases={Phase.generate},
+        suppress_health_check={HealthCheck.function_scoped_fixture},
+    )
     async def test_main(
         self,
         *,
         data: DataObject,
-        name: str,
-        case: tuple[
-            SearchStrategy[Any], PolarsDataType, Any, Callable[[Any, Any], bool]
-        ],
+        strategy: SearchStrategy[Any],
+        pl_dtype: PolarsDataType,
+        col_type: Any,
+        check: Callable[[Any, Any], bool],
+        test_engine: AsyncEngine,
     ) -> None:
-        strategy, pl_dtype, col_type, check = case
-        values = data.draw(lists(strategy, max_size=100))
+        values = data.draw(lists(strategy, min_size=1))
         df = DataFrame({"value": values}, schema={"value": pl_dtype})
-        table = self._make_table(name, col_type)
-        engine = await sqlalchemy_engines(data, table)
-        await insert_dataframe(df, table, engine)
+        table = self._make_table(col_type)
+        await insert_dataframe(df, table, test_engine)
         sel = select(table.c["value"])
-        async with engine.begin() as conn:
+        async with test_engine.begin() as conn:
             results = (await conn.execute(sel)).scalars().all()
         for r, v in zip(results, values, strict=True):
             assert ((r is None) == (v is None)) or check(r, v)
 
-    @given(data=data(), name=_table_names())
-    @settings(phases={Phase.generate})
-    async def test_assume_exists_with_empty(
-        self, *, data: DataObject, name: str
-    ) -> None:
+    async def test_assume_exists_with_empty(self, *, test_engine: AsyncEngine) -> None:
         df = DataFrame(schema={"value": pl.Boolean})
-        table = self._make_table(name, sqlalchemy.Boolean)
-        engine = await sqlalchemy_engines(data, table)
-        await ensure_tables_created(engine, table)
-        await insert_dataframe(df, table, engine, assume_tables_exist=True)
+        table = self._make_table(sqlalchemy.Boolean)
+        await ensure_tables_created(test_engine, table)
+        await insert_dataframe(df, table, test_engine, assume_tables_exist=True)
 
-    @given(data=data(), name=_table_names(), value=booleans())
-    @settings(phases={Phase.generate})
+    @mark.parametrize("value", [param(True), param(False)])
     async def test_assume_exists_with_non_empty(
-        self, *, data: DataObject, name: str, value: bool
+        self, *, value: bool, test_engine: AsyncEngine
     ) -> None:
         df = DataFrame([(value,)], schema={"value": pl.Boolean})
-        table = self._make_table(name, sqlalchemy.Boolean)
-        engine = await sqlalchemy_engines(data, table)
+        table = self._make_table(sqlalchemy.Boolean)
+
         with raises(
             (OperationalError, ProgrammingError), match="(no such table|does not exist)"
         ):
-            await insert_dataframe(df, table, engine, assume_tables_exist=True)
+            await insert_dataframe(df, table, test_engine, assume_tables_exist=True)
 
-    @given(data=data(), name=_table_names())
-    @settings(phases={Phase.generate})
-    async def test_empty(self, *, data: DataObject, name: str) -> None:
+    async def test_empty(self, *, test_engine: AsyncEngine) -> None:
         df = DataFrame(schema={"value": pl.Boolean})
-        table = self._make_table(name, sqlalchemy.Boolean)
-        engine = await sqlalchemy_engines(data, table)
-        await insert_dataframe(df, table, engine, assume_tables_exist=False)
+        table = self._make_table(sqlalchemy.Boolean)
+        await insert_dataframe(df, table, test_engine, assume_tables_exist=False)
         sel = select(table.c["value"])
-        async with engine.begin() as conn:
+        async with test_engine.begin() as conn:
             results = (await conn.execute(sel)).scalars().all()
         assert results == []
 
-    @given(data=data(), name=_table_names())
-    @settings(phases={Phase.generate})
-    async def test_upsert(self, *, data: DataObject, name: str) -> None:
-        values = data.draw(_upsert_lists())
+    @given(values=_upsert_lists(min_size=1))
+    @settings(
+        max_examples=1,
+        phases={Phase.generate},
+        suppress_health_check={HealthCheck.function_scoped_fixture},
+    )
+    async def test_upsert(
+        self, *, values: list[tuple[int, bool, bool | None]], test_engine: AsyncEngine
+    ) -> None:
         df = DataFrame(
             values,
             schema={"id_": Int64, "init": pl.Boolean, "post": pl.Boolean},
             orient="row",
         )
-        table = self._make_table(name, sqlalchemy.Boolean)
-        engine = await sqlalchemy_engines(data, table)
+        table = self._make_table(sqlalchemy.Boolean)
         await insert_dataframe(
             df.select("id_", col("init").alias("value")),
             table,
-            engine,
+            test_engine,
             upsert="selected",
         )
         sel = select(table)
-        async with engine.begin() as conn:
+        async with test_engine.begin() as conn:
             results = (await conn.execute(sel)).all()
         assert set(results) == set(df.select("id_", "init").rows())
         await insert_dataframe(
             df.select("id_", col("post").alias("value")).drop_nulls(),
             table,
-            engine,
+            test_engine,
             upsert="selected",
         )
-        async with engine.begin() as conn:
+        async with test_engine.begin() as conn:
             results = (await conn.execute(sel)).all()
         expected = df.select(
             "id_", when(col("post").is_null()).then("init").otherwise("post")
         )
         assert set(results) == set(expected.rows())
 
-    @given(data=data(), name=_table_names(), value=booleans())
-    @settings(phases={Phase.generate})
-    async def test_error(self, *, data: DataObject, name: str, value: bool) -> None:
+    @mark.parametrize("value", [param(True), param(False)])
+    async def test_error(self, *, value: bool, test_engine: AsyncEngine) -> None:
         df = DataFrame([(value,)], schema={"other": pl.Boolean})
-        table = self._make_table(name, sqlalchemy.Boolean)
-        engine = await sqlalchemy_engines(data, table)
+        table = self._make_table(sqlalchemy.Boolean)
         with raises(
             InsertDataFrameError,
             match="Non-empty DataFrame must resolve to at least 1 item",
         ):
-            _ = await insert_dataframe(df, table, engine)
+            _ = await insert_dataframe(df, table, test_engine)
 
-    def _make_table(self, name: str, type_: Any, /) -> Table:
+    def _make_table(self, type_: Any, /) -> Table:
         return Table(
-            name,
+            _table_names(),
             MetaData(),
             Column("id_", Integer, primary_key=True),
             Column("value", type_),
@@ -396,126 +390,133 @@ class TestInsertDataFrameMapDFSchemaToTable:
 
 
 class TestSelectToDataFrame:
-    @given(
-        data=data(),
-        name=_table_names(),
-        case=sampled_from([
+    @given(data=data())
+    @mark.parametrize(
+        ("strategy", "pl_dtype", "col_type"),
+        [
             (strategy, pl_dtype, col_type)
             for (strategy, pl_dtype, col_type, _) in _CASES_SELECT
-        ]),
+        ],
+    )
+    @settings(
+        max_examples=1,
+        phases={Phase.generate},
+        suppress_health_check={HealthCheck.function_scoped_fixture},
     )
-    @settings(phases={Phase.generate})
     async def test_main(
         self,
         *,
         data: DataObject,
-        name: str,
-        case: tuple[SearchStrategy[Any], PolarsDataType, Any],
+        strategy: SearchStrategy[Any],
+        pl_dtype: PolarsDataType,
+        col_type: Any,
+        test_engine: AsyncEngine,
     ) -> None:
-        strategy, pl_dtype, col_type = case
-        values = data.draw(lists(strategy, max_size=100))
+        values = data.draw(lists(strategy, min_size=1))
         df = DataFrame({"value": values}, schema={"value": pl_dtype})
-        table = self._make_table(name, col_type)
-        engine = await sqlalchemy_engines(data, table)
-        await insert_dataframe(df, table, engine)
+        table = self._make_table(col_type)
+        await insert_dataframe(df, table, test_engine)
         sel = select(table.c["value"])
-        result = await select_to_dataframe(sel, engine)
+        result = await select_to_dataframe(sel, test_engine)
         assert_frame_equal(result, df)
 
-    @given(
-        data=data(),
-        name=_table_names(),
-        values=lists(booleans() | none(), min_size=1, max_size=100),
-        sr_name=sampled_from(["Value", "value"]),
+    @given(values=lists(booleans() | none(), min_size=1))
+    @mark.parametrize("sr_name", [param("Value"), param("value")])
+    @settings(
+        max_examples=1,
+        phases={Phase.generate},
+        suppress_health_check={HealthCheck.function_scoped_fixture},
     )
-    @settings(phases={Phase.generate})
     async def test_snake(
-        self, *, data: DataObject, name: str, values: list[bool], sr_name: str
+        self, *, values: list[bool], sr_name: str, test_engine: AsyncEngine
     ) -> None:
         df = DataFrame({sr_name: values}, schema={sr_name: pl.Boolean})
-        table = self._make_table(name, sqlalchemy.Boolean, title=True)
-        engine = await sqlalchemy_engines(data, table)
-        await insert_dataframe(df, table, engine, snake=True)
+        table = self._make_table(sqlalchemy.Boolean, title=True)
+        await insert_dataframe(df, table, test_engine, snake=True)
         sel = select(table.c["Value"])
-        result = await select_to_dataframe(sel, engine, snake=True)
+        result = await select_to_dataframe(sel, test_engine, snake=True)
         expected = DataFrame({"value": values}, schema={"value": pl.Boolean})
         assert_frame_equal(result, expected)
 
-    @given(
-        data=data(),
-        name=_table_names(),
-        values=lists(integers(0, 100), min_size=1, max_size=100, unique=True),
-        batch_size=integers(1, 10),
+    @given(values=lists(int32s(), min_size=1, unique=True), batch_size=integers(1, 10))
+    @settings(
+        max_examples=1,
+        phases={Phase.generate},
+        suppress_health_check={HealthCheck.function_scoped_fixture},
     )
-    @settings(phases={Phase.generate})
     async def test_batch(
-        self, *, data: DataObject, name: str, values: list[int], batch_size: int
+        self, *, values: list[int], batch_size: int, test_engine: AsyncEngine
     ) -> None:
-        df, table, engine, sel = await self._prepare_feature_test(data, name, values)
-        await insert_dataframe(df, table, engine)
-        dfs = await select_to_dataframe(sel, engine, batch_size=batch_size)
+        df, table, sel = await self._prepare_feature_test(values)
+        await insert_dataframe(df, table, test_engine)
+        dfs = await select_to_dataframe(sel, test_engine, batch_size=batch_size)
         self._assert_batch_results(dfs, batch_size, values)
 
     @given(
         data=data(),
-        name=_table_names(),
-        values=lists(integers(0, 100), min_size=1, max_size=100, unique=True),
+        values=lists(int32s(), min_size=1, unique=True),
         in_clauses_chunk_size=integers(1, 10),
     )
-    @settings(phases={Phase.generate})
+    @settings(
+        max_examples=1,
+        phases={Phase.generate},
+        suppress_health_check={HealthCheck.function_scoped_fixture},
+    )
     async def test_in_clauses_non_empty(
         self,
         *,
         data: DataObject,
-        name: str,
         values: list[int],
         in_clauses_chunk_size: int,
+        test_engine: AsyncEngine,
     ) -> None:
-        df, table, engine, sel = await self._prepare_feature_test(data, name, values)
-        await insert_dataframe(df, table, engine)
-        in_values = data.draw(sets(sampled_from(values)))
+        df, table, sel = await self._prepare_feature_test(values)
+        await insert_dataframe(df, table, test_engine)
+        in_values = data.draw(sets(sampled_from(values), min_size=1))
         df = await select_to_dataframe(
             sel,
-            engine,
+            test_engine,
             in_clauses=(table.c["value"], in_values),
             in_clauses_chunk_size=in_clauses_chunk_size,
         )
         check_polars_dataframe(df, height=len(in_values), schema_list={"value": Int64})
         assert set(df["value"].to_list()) == in_values
 
-    @given(data=data(), name=_table_names())
-    @settings(phases={Phase.generate})
-    async def test_in_clauses_empty(self, *, data: DataObject, name: str) -> None:
-        table = self._make_table(name, Integer)
-        engine = await sqlalchemy_engines(data, table)
-        await ensure_tables_created(engine, table)
+    async def test_in_clauses_empty(self, *, test_engine: AsyncEngine) -> None:
+        table = self._make_table(Integer)
+        await ensure_tables_created(test_engine, table)
         sel = select(table.c["value"])
-        df = await select_to_dataframe(sel, engine, in_clauses=(table.c["value"], []))
+        df = await select_to_dataframe(
+            sel, test_engine, in_clauses=(table.c["value"], [])
+        )
         check_polars_dataframe(df, height=0, schema_list={"value": Int64})
 
     @given(
         data=data(),
-        name=_table_names(),
-        values=lists(integers(0, 100), min_size=1, max_size=100, unique=True),
+        values=lists(int32s(), min_size=1, unique=True),
         batch_size=integers(1, 10),
         in_clauses_chunk_size=integers(1, 10),
     )
-    @settings(phases={Phase.generate})
+    @settings(
+        max_examples=1,
+        phases={Phase.generate},
+        suppress_health_check={HealthCheck.function_scoped_fixture},
+    )
     async def test_batch_and_in_clauses(
         self,
         *,
         data: DataObject,
-        name: str,
         values: list[int],
         batch_size: int,
         in_clauses_chunk_size: int,
+        test_engine: AsyncEngine,
     ) -> None:
-        df, table, engine, sel = await self._prepare_feature_test(data, name, values)
-        await insert_dataframe(df, table, engine)
-        in_values = data.draw(sets(sampled_from(values)))
+        df, table, sel = await self._prepare_feature_test(values)
+        await insert_dataframe(df, table, test_engine)
+        in_values = data.draw(sets(sampled_from(values), min_size=1))
         async_dfs = await select_to_dataframe(
             sel,
-            engine,
+            test_engine,
             batch_size=batch_size,
             in_clauses=(table.c["value"], in_values),
             in_clauses_chunk_size=in_clauses_chunk_size,
@@ -537,22 +538,21 @@ class TestSelectToDataFrame:
             seen.update(df_i["value"].to_list())
         assert seen == values
 
-    def _make_table(self, name: str, type_: Any, /, *, title: bool = False) -> Table:
+    def _make_table(self, type_: Any, /, *, title: bool = False) -> Table:
         return Table(
-            name,
+            _table_names(),
             MetaData(),
             Column("Id" if title else "id", Integer, primary_key=True),
             Column("Value" if title else "value", type_),
         )
 
     async def _prepare_feature_test(
-        self, data: DataObject, name: str, values: Sequence[int], /
-    ) -> tuple[DataFrame, Table, AsyncEngine, Select[Any]]:
+        self, values: Sequence[int], /
+    ) -> tuple[DataFrame, Table, Select[Any]]:
         df = DataFrame({"value": values}, schema={"value": Int64})
-        table = self._make_table(name, Integer)
-        engine = await sqlalchemy_engines(data, table)
+        table = self._make_table(Integer)
         sel = select(table.c["value"])
-        return df, table, engine, sel
+        return df, table, sel
 
 
 class TestSelectToDataFrameApplySnake:
@@ -653,27 +653,30 @@ class TestSelectToDataFrameMapTableColumnTypeToDType:
 
 class TestSelectToDataFrameYieldSelectsWithInClauses:
     @given(
-        data=data(),
-        name=_table_names(),
-        values=sets(integers(), max_size=100),
+        values=sets(int32s(), min_size=1),
         in_clauses_chunk_size=integers(1, 10) | none(),
         chunk_size_frac=floats(0.1, 10.0),
     )
+    @settings(
+        max_examples=1,
+        phases={Phase.generate},
+        suppress_health_check={HealthCheck.function_scoped_fixture},
+    )
     async def test_main(
         self,
         *,
-        data: DataObject,
-        name: str,
         values: set[int],
         in_clauses_chunk_size: int | None,
         chunk_size_frac: float,
+        test_engine: AsyncEngine,
     ) -> None:
-        table = Table(name, MetaData(), Column("id", Integer, primary_key=True))
-        engine = await sqlalchemy_engines(data, table)
+        table = Table(
+            _table_names(), MetaData(), Column("id", Integer, primary_key=True)
+        )
         sel = select(table.c["id"])
         sels = _select_to_dataframe_yield_selects_with_in_clauses(
             sel,
-            engine,
+            test_engine,
             (table.c["id"], values),
             in_clauses_chunk_size=in_clauses_chunk_size,
             chunk_size_frac=chunk_size_frac,
