@@ -25,10 +25,8 @@ from polars import (
 )
 from sqlalchemy import Column, Select, select
 from sqlalchemy.exc import DuplicateColumnError
-from sqlalchemy.ext.asyncio import AsyncEngine, create_async_engine
 
-from utilities.asyncio import timeout_dur
-from utilities.datetime import is_subclass_date_not_datetime
+from utilities.asyncio import timeout_td
 from utilities.functions import identity
 from utilities.iterables import (
     CheckDuplicatesError,
@@ -49,6 +47,7 @@ from utilities.sqlalchemy import (
     upsert_items,
 )
 from utilities.text import snake_case
+from utilities.typing import is_subclass_gen
 from utilities.zoneinfo import UTC
 
 if TYPE_CHECKING:
@@ -60,18 +59,13 @@ if TYPE_CHECKING:
         Mapping,
     )
 
-    from polars._typing import (
-        PolarsDataType,  # pyright: ignore[reportPrivateImportUsage]
-        SchemaDict,  # pyright: ignore[reportPrivateImportUsage]
-    )
+    from polars._typing import PolarsDataType, SchemaDict
+    from sqlalchemy.ext.asyncio import AsyncEngine
     from sqlalchemy.sql import ColumnCollection
     from sqlalchemy.sql.base import ReadOnlyColumnCollection
-    from tenacity.retry import RetryBaseT
-    from tenacity.stop import StopBaseT
-    from tenacity.wait import WaitBaseT
+    from whenever import TimeDelta
 
-    import utilities.types
-    from utilities.types import TimeZoneLike
+    from utilities.types import MaybeType, TimeZoneLike
 
 
 async def insert_dataframe(
@@ -84,16 +78,16 @@ async def insert_dataframe(
     chunk_size_frac: float = CHUNK_SIZE_FRAC,
     assume_tables_exist: bool = False,
     upsert: Literal["selected", "all"] | None = None,
-    timeout_create: utilities.types.Duration | None = None,
+    timeout_create: TimeDelta | None = None,
     error_create: type[Exception] = TimeoutError,
-    timeout_insert: utilities.types.Duration | None = None,
+    timeout_insert: TimeDelta | None = None,
     error_insert: type[Exception] = TimeoutError,
 ) -> None:
     """Insert/upsert a DataFrame into a database."""
     mapping = _insert_dataframe_map_df_schema_to_table(
         df.schema, table_or_orm, snake=snake
     )
-    items = df.select(mapping).rename(mapping).to_dicts()
+    items = df.select(*mapping).rename(mapping).to_dicts()
     if len(items) == 0:
         if not df.is_empty():
             raise InsertDataFrameError(df=df)
@@ -201,14 +195,14 @@ def _insert_dataframe_check_df_and_db_types(
     dtype: PolarsDataType, db_col_type: type, /
 ) -> bool:
     return (
-        ((dtype == pl.Boolean) and issubclass(db_col_type, bool))
-        or ((dtype == Date) and is_subclass_date_not_datetime(db_col_type))
-        or ((dtype == Datetime) and issubclass(db_col_type, dt.datetime))
+        ((dtype == pl.Boolean) and is_subclass_gen(db_col_type, bool))
+        or ((dtype == Date) and is_subclass_gen(db_col_type, dt.date))
+        or ((dtype == Datetime) and is_subclass_gen(db_col_type, dt.datetime))
         or ((dtype == Float64) and issubclass(db_col_type, float))
-        or ((dtype == Int32) and issubclass(db_col_type, int))
-        or ((dtype == Int64) and issubclass(db_col_type, int))
-        or ((dtype == UInt32) and issubclass(db_col_type, int))
-        or ((dtype == UInt64) and issubclass(db_col_type, int))
+        or ((dtype == Int32) and is_subclass_gen(db_col_type, int))
+        or ((dtype == Int64) and is_subclass_gen(db_col_type, int))
+        or ((dtype == UInt32) and is_subclass_gen(db_col_type, int))
+        or ((dtype == UInt64) and is_subclass_gen(db_col_type, int))
         or ((dtype == String) and issubclass(db_col_type, str))
     )
 
@@ -234,10 +228,7 @@ async def select_to_dataframe(
     in_clauses: tuple[Column[Any], Iterable[Any]] | None = None,
     in_clauses_chunk_size: int | None = None,
     chunk_size_frac: float = CHUNK_SIZE_FRAC,
-    stop: StopBaseT | None = None,
-    wait: WaitBaseT | None = None,
-    retry: RetryBaseT | None = None,
-    timeout: utilities.types.Duration | None = None,
+    timeout: TimeDelta | None = None,
     **kwargs: Any,
 ) -> DataFrame: ...
 @overload
@@ -252,10 +243,7 @@ async def select_to_dataframe(
     in_clauses: None = None,
     in_clauses_chunk_size: int | None = None,
     chunk_size_frac: float = CHUNK_SIZE_FRAC,
-    stop: StopBaseT | None = None,
-    wait: WaitBaseT | None = None,
-    retry: RetryBaseT | None = None,
-    timeout: utilities.types.Duration | None = None,
+    timeout: TimeDelta | None = None,
     **kwargs: Any,
 ) -> Iterable[DataFrame]: ...
 @overload
@@ -270,10 +258,7 @@ async def select_to_dataframe(
     in_clauses: tuple[Column[Any], Iterable[Any]],
     in_clauses_chunk_size: int | None = None,
     chunk_size_frac: float = CHUNK_SIZE_FRAC,
-    stop: StopBaseT | None = None,
-    wait: WaitBaseT | None = None,
-    retry: RetryBaseT | None = None,
-    timeout: utilities.types.Duration | None = None,
+    timeout: TimeDelta | None = None,
     **kwargs: Any,
 ) -> AsyncIterable[DataFrame]: ...
 @overload
@@ -288,10 +273,7 @@ async def select_to_dataframe(
     in_clauses: tuple[Column[Any], Iterable[Any]] | None = None,
     in_clauses_chunk_size: int | None = None,
     chunk_size_frac: float = CHUNK_SIZE_FRAC,
-    stop: StopBaseT | None = None,
-    wait: WaitBaseT | None = None,
-    retry: RetryBaseT | None = None,
-    timeout: utilities.types.Duration | None = None,
+    timeout: TimeDelta | None = None,
     **kwargs: Any,
 ) -> DataFrame | Iterable[DataFrame] | AsyncIterable[DataFrame]: ...
 async def select_to_dataframe(
@@ -305,32 +287,16 @@ async def select_to_dataframe(
     in_clauses: tuple[Column[Any], Iterable[Any]] | None = None,
     in_clauses_chunk_size: int | None = None,
     chunk_size_frac: float = CHUNK_SIZE_FRAC,
-    timeout: utilities.types.Duration | None = None,
-    error: type[Exception] = TimeoutError,
+    timeout: TimeDelta | None = None,
+    error: MaybeType[BaseException] = TimeoutError,
     **kwargs: Any,
 ) -> DataFrame | Iterable[DataFrame] | AsyncIterable[DataFrame]:
     """Read a table from a database into a DataFrame."""
-    if not issubclass(AsyncEngine, type(engine)):
-        # for handling testing
-        engine = create_async_engine(engine.url)
-        return await select_to_dataframe(
-            sel,
-            engine,
-            snake=snake,
-            time_zone=time_zone,
-            batch_size=batch_size,
-            in_clauses=in_clauses,
-            in_clauses_chunk_size=in_clauses_chunk_size,
-            chunk_size_frac=chunk_size_frac,
-            timeout=timeout,
-            error=error,
-            **kwargs,
-        )
     if snake:
         sel = _select_to_dataframe_apply_snake(sel)
     schema = _select_to_dataframe_map_select_to_df_schema(sel, time_zone=time_zone)
     if in_clauses is None:
-        async with timeout_dur(duration=timeout, error=error):
+        async with timeout_td(timeout, error=error):
             return read_database(
                 sel,
                 cast("Any", engine),
@@ -347,7 +313,7 @@ async def select_to_dataframe(
         chunk_size_frac=chunk_size_frac,
     )
     if batch_size is None:
-        async with timeout_dur(duration=timeout, error=error):
+        async with timeout_td(timeout, error=error):
             dfs = [
                 await select_to_dataframe(
                     sel,
@@ -368,7 +334,7 @@ async def select_to_dataframe(
             return DataFrame(schema=schema)
 
     async def yield_dfs() -> AsyncIterator[DataFrame]:
-        async with timeout_dur(duration=timeout, error=error):
+        async with timeout_td(timeout, error=error):
             for sel_i in sels:
                 for df in await select_to_dataframe(
                     sel_i,
@@ -414,15 +380,15 @@ def _select_to_dataframe_map_table_column_type_to_dtype(
     """Map a table column type to a polars type."""
     type_use = type_() if isinstance(type_, type) else type_
     py_type = type_use.python_type
-    if issubclass(py_type, bool):
+    if is_subclass_gen(py_type, bool):
         return pl.Boolean
     if issubclass(py_type, bytes):
         return Binary
     if issubclass(py_type, decimal.Decimal):
         return pl.Decimal
-    if issubclass(py_type, dt.date) and not issubclass(py_type, dt.datetime):
+    if is_subclass_gen(py_type, dt.date):
         return pl.Date
-    if issubclass(py_type, dt.datetime):
+    if is_subclass_gen(py_type, dt.datetime):
         has_tz: bool = type_use.timezone
         return zoned_datetime(time_zone=time_zone) if has_tz else Datetime()
     if issubclass(py_type, dt.time):
@@ -431,7 +397,7 @@ def _select_to_dataframe_map_table_column_type_to_dtype(
         return pl.Duration
     if issubclass(py_type, float):
         return Float64
-    if issubclass(py_type, int):
+    if is_subclass_gen(py_type, int):
         return Int64
     if issubclass(py_type, UUID | str):
         return String
@@ -467,7 +433,7 @@ def _select_to_dataframe_yield_selects_with_in_clauses(
     in_col, in_values = in_clauses
     if in_clauses_chunk_size is None:
         chunk_size = get_chunk_size(
-            engine, chunk_size_frac=chunk_size_frac, scaling=max_length
+            engine, chunk_size_frac=chunk_size_frac, max_length=max_length
         )
     else:
         chunk_size = in_clauses_chunk_size
