@@ -1,13 +1,15 @@
 from __future__ import annotations
 
 from logging import getLogger
-from typing import TYPE_CHECKING
+from typing import TYPE_CHECKING, cast
 
 from tzlocal import get_localzone
 
 if TYPE_CHECKING:
     from zoneinfo import ZoneInfo
 
+    from utilities.types import TimeZone
+
 
 def get_local_time_zone() -> ZoneInfo:
     """Get the local time zone, with the logging disabled."""
@@ -19,4 +21,8 @@ def get_local_time_zone() -> ZoneInfo:
     return time_zone
 
 
-__all__ = ["get_local_time_zone"]
+LOCAL_TIME_ZONE = get_local_time_zone()
+LOCAL_TIME_ZONE_NAME = cast("TimeZone", LOCAL_TIME_ZONE.key)
+
+
+__all__ = ["LOCAL_TIME_ZONE", "LOCAL_TIME_ZONE_NAME", "get_local_time_zone"]
